#!/usr/bin/env python

"""

config.py
=========

Creates and reads config file using ConfigParser::

    [core]
        keyword = x86
        overlay path = ~/src/my-overlay/
        format = ansi
"""

from ConfigParser import RawConfigParser as _Parser
from ConfigParser import NoSectionError, NoOptionError
import os
import logging
from logging.config import fileConfig

from g_pypi.portage_utils import get_keyword, get_portdir_overlay, get_repo_name


__docformat__ = 'restructuredtext'

CONFIG_DIR = os.path.expanduser("~/.g-pypi")

def get_rc_filename():
    """Return rc_file filename"""
    return os.path.join(CONFIG_DIR, "g-pypirc")

def setup_logger():
    "Possibly overrides 'g-pypi' logger stored in logging package"
    logger = logging.getLogger('g-pypi')
    try:
        fileConfig(fname=get_rc_filename())
    except (NoSectionError, NoOptionError), e:
        logger.info('using default logger')
        logger.warning(e)
    return logging.getLogger('g-pypi')

def setup_config(cls=None):
    """Read config file, create if it doesn't exist"""
    if not cls:
        cls = Parser
    config = cls()
    config.add_section('options')
    config.set('options', 'background', 'dark')
    config.add_section('core')
    config.set('core', 'keyword', get_keyword())
    config.set('core', 'overlay', get_repo_name(get_portdir_overlay()))
    config.set('core', 'overlay_path', '')
    config.set('core', 'format', 'ansi')
    config.read([get_rc_filename()])
    return config

class Parser (_Parser):
    "Extended ConfigParser with `setboolean()` and similar methods."
    def setboolean(self, section, option, value):
        self.set(section, option, str(value).lower())

    def get(self, section, option, default=None):
        logger = logging.getLogger('g-pypi')
        try:
            value = _Parser.get(self, section, option)
        except (NoSectionError, NoOptionError), e:
            logger.warning(str(e))
            value = default
        return value

CONFIG = setup_config()
setup_logger()
